package net.sewio.rtls.websocket;

import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;

import org.eclipse.jetty.websocket.api.Session;
import org.eclipse.jetty.websocket.api.annotations.OnWebSocketClose;
import org.eclipse.jetty.websocket.api.annotations.OnWebSocketConnect;
import org.eclipse.jetty.websocket.api.annotations.OnWebSocketMessage;
import org.eclipse.jetty.websocket.api.annotations.WebSocket;

/**
 * Basic sewiortls WebSocket Client
 */
@WebSocket(maxTextMessageSize = 64 * 1024)
public class SimpleRtlsWebSocket
{
    private Session session;

    public SimpleRtlsWebSocket(){

    }

    @OnWebSocketClose
    public void onClose(int statusCode, String reason)
    {
        System.out.printf("Connection closed: %d - %s%n",statusCode,reason);
        this.session = null;
    }

    @OnWebSocketConnect
    public void onConnect(Session session)
    {
        System.out.printf("Got connect: %s%n",session);
        this.session = session;       
    }

    public void sendMessage(String msg)
    {
        try
        {
            Future<Void> fut;
            fut = session.getRemote().sendStringByFuture(msg);
            fut.get(2,TimeUnit.SECONDS);
        }
        catch (Throwable t)
        {
            t.printStackTrace();
        }
    }
    
    public void subscribe(String xApiKey, String FEED_ID)
    {
    	String method = "subscribe";
    	String msg = "{\"headers\":{\"X-ApiKey\":\""+ xApiKey +"\"},\"method\":\"" + method + "\", \"resource\":\"/feeds/" + FEED_ID + "\"}";
    	System.out.printf("Sending msg: %s%n",msg);
    	sendMessage(msg);
    }
    public void unsubscribe(String xApiKey, String FEED_ID)
    {
    	String method = "unsubscribe";
    	String msg = "{\"headers\":{\"X-ApiKey\":\""+ xApiKey +"\"},\"method\":\"" + method + "\", \"resource\":\"/feeds/" + FEED_ID + "\"}";
    	System.out.printf("Sending msg: %s%n",msg);
    	sendMessage(msg);
    }
    public void put(String xApiKey, String FEED_ID, double posX, double posY)
    {
    	String method = "put";
    	String msg = "{\"headers\":{\"X-ApiKey\":\"" + xApiKey +"\"},\"method\":\"" + method + "\",options:{savetoDB:false}, \"body\":{\"id\":" + FEED_ID + ",\"datastreams\":[{\"id\":\"posX\",\"current_value\":" + posX + "},{\"id\":\"posY\",\"current_value\":" + posY + "}]}, \"resource\":\"/feeds/" + FEED_ID + "\"}";
    	System.out.printf("Sending msg: %s%n",msg);
        sendMessage(msg);
    }   
    public boolean isConnected()
    {
    	if (session != null){
	        return session.isOpen();
    	}
    	else
    		return false;
    }

    @OnWebSocketMessage
    public void onMessage(String msg)
    {
        System.out.printf("Got msg: %s%n",msg);
    }
}
